explain

package
v0.14.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 16, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrDependencyNotFound = errors.New("dependency not found")

ErrDependencyNotFound indicates the requested package was not found.

Functions

func GraphFromPaths

func GraphFromPaths(source *sdk.Graph, paths []Path) (*sdk.Graph, error)

GraphFromPaths returns a focused subgraph of source containing only the packages and edges that appear in the supplied explain paths.

Types

type Path

type Path = output.DependencyPath

Path is an alias for output.DependencyPath.

func FindWhy

func FindWhy(deps *sdk.Graph, query string) (output.PackageRef, []Path, error)

FindWhy resolves a target package and returns all root-to-target paths.

func FindWhyPackage

func FindWhyPackage(deps *sdk.Graph, query string) (*sdk.Dependency, []Path, error)

FindWhyPackage resolves a target package and returns the package plus all root-to-target paths.

Jump to